@@ -1,6 +1,7 @@
 var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();
 
-import React, { PropTypes } from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 import { Seq } from 'immutable';
 import FormSelect from '../../components/style/form-select';
 import FormLabel from '../../components/style/form-label';
@@ -15,6 +16,18 @@ export default function PropertyEnum(_ref) {
       sourceElement = _ref.sourceElement,
       internalState = _ref.internalState;
 
+
+  var update = function update(val) {
+
+    if (configs.hook) {
+      return configs.hook(val).then(function (_val) {
+        return onUpdate(_val);
+      });
+    }
+
+    return onUpdate(val);
+  };
+
   return React.createElement(
     'table',
     { className: 'PropertyEnum', style: tableStyle },
@@ -39,7 +52,7 @@ export default function PropertyEnum(_ref) {
           React.createElement(
             FormSelect,
             { value: value, onChange: function onChange(event) {
-                return onUpdate(event.target.value);
+                return update(event.target.value);
               } },
             Seq(configs.values).entrySeq().map(function (_ref2) {
               var _ref3 = _slicedToArray(_ref2, 2),
