@@ -1,4 +1,5 @@
-import React, { PropTypes } from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 import FormLabel from '../../components/style/form-label';
 import Button from '../../components/style/button';
 
@@ -12,6 +13,18 @@ export default function PropertyToggle(_ref) {
       sourceElement = _ref.sourceElement,
       internalState = _ref.internalState;
 
+
+  var update = function update(val) {
+
+    if (configs.hook) {
+      return configs.hook(val).then(function (_val) {
+        return onUpdate(_val);
+      });
+    }
+
+    return onUpdate(val);
+  };
+
   return React.createElement(
     'table',
     { className: 'PropertyToggle', style: tableStyle },
@@ -36,7 +49,7 @@ export default function PropertyToggle(_ref) {
           React.createElement(
             Button,
             { onClick: function onClick(e) {
-                return onUpdate(!value);
+                return update(!value);
               }, size: 'small' },
             configs.actionName
           )
