@@ -1,4 +1,5 @@
-import React, {PropTypes} from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 import FormLabel from '../../components/style/form-label'
 import FormColorInput from '../../components/style/form-color-input';
 
@@ -6,6 +7,17 @@ const tableStyle = { width: "100%", borderSpacing: "2px 0", marginBottom: "2px"
 const firstTdStyle = { width: '6em' };
 
 export default function PropertyColor({value, onUpdate, configs, sourceElement, internalState}) {
+
+  let update = (val) => {
+
+    if( configs.hook )
+    {
+      return configs.hook( val ).then( _val => { return onUpdate(_val); } );
+    }
+
+    return onUpdate( val );
+  };
+
   return (
     <table className="PropertyColor" style={tableStyle}>
       <tbody>
@@ -14,7 +26,7 @@ export default function PropertyColor({value, onUpdate, configs, sourceElement,
             <FormLabel>{configs.label}</FormLabel>
           </td>
           <td>
-            <FormColorInput value={value} onChange={event => onUpdate(event.target.value)}/>
+            <FormColorInput value={value} onChange={event => update(event.target.value)}/>
           </td>
         </tr>
       </tbody>
