@@ -1,4 +1,5 @@
-import React, {PropTypes} from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 import {Seq} from 'immutable';
 import FormSelect from '../../components/style/form-select';
 import FormLabel from '../../components/style/form-label';
@@ -7,13 +8,24 @@ const tableStyle = { width: "100%", borderSpacing: "2px 0", marginBottom: "2px"
 const firstTdStyle = { width: '6em' };
 
 export default function PropertyEnum({value, onUpdate, configs, sourceElement, internalState}) {
+
+  let update = (val) => {
+
+    if( configs.hook )
+    {
+      return configs.hook( val ).then( _val => { return onUpdate(_val); } );
+    }
+
+    return onUpdate( val );
+  };
+
   return (
     <table className="PropertyEnum" style={tableStyle}>
       <tbody>
         <tr>
           <td style={firstTdStyle}><FormLabel>{configs.label}</FormLabel></td>
           <td>
-            <FormSelect value={value} onChange={event => onUpdate(event.target.value)}>
+            <FormSelect value={value} onChange={event => update(event.target.value)}>
               {Seq(configs.values)
                 .entrySeq()
                 .map(([key, value]) => <option key={key} value={key}>{value}</option>)}
