@@ -1,4 +1,5 @@
-import React, {PropTypes} from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 import { UNITS_LENGTH, UNIT_CENTIMETER } from './../../constants';
 import convert from 'convert-units';
 import FormLabel from '../../components/style/form-label'
@@ -21,14 +22,18 @@ export default function PropertyLengthMeasure({value, onUpdate, configs, sourceE
   let update = (lengthInput, unitInput) => {
 
     let newLength = toFixedFloat(lengthInput);
+    let merged = value.merge({
+      length : unitInput !== UNIT_CENTIMETER ? convert(newLength).from(unitInput).to(UNIT_CENTIMETER) : newLength,
+      _length : lengthInput,
+      _unit: unitInput
+    });
 
-    onUpdate(
-      value.merge({
-        length : unitInput !== UNIT_CENTIMETER ? convert(newLength).from(unitInput).to(UNIT_CENTIMETER) : newLength,
-        _length : lengthInput,
-        _unit: unitInput
-      })
-    );
+    if( configs.hook )
+    {
+      return configs.hook( merged ).then( val => { return onUpdate(val); } );
+    }
+
+    return onUpdate( merged );
   };
 
   return (
