@@ -1,4 +1,5 @@
-import React, {PropTypes} from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 import FormLabel from '../../components/style/form-label'
 import FormNumberInput from '../../components/style/form-number-input';
 
@@ -7,13 +8,19 @@ const firstTdStyle = { width: '6em' };
 
 export default function PropertyNumber({value, onUpdate, configs, sourceElement, internalState}) {
 
-  let update = (value) => {
-    let number = parseFloat(value);
+  let update = (val) => {
+    let number = parseFloat(val);
 
     if (isNaN(number)) {
       number = 0;
     }
-    return onUpdate(number);
+
+    if( configs.hook )
+    {
+      return configs.hook( number ).then( _val => { return onUpdate(_val); } );
+    }
+
+    return onUpdate( number );
   };
 
   return (
