@@ -1,4 +1,5 @@
-import React, {PropTypes} from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 import FormLabel from '../../components/style/form-label'
 import FormTextInput from '../../components/style/form-text-input';
 
@@ -6,6 +7,17 @@ const tableStyle = { width: "100%", borderSpacing: "2px 0", marginBottom: "2px"
 const firstTdStyle = { width: '6em' };
 
 export default function PropertyString({value, onUpdate, configs, sourceElement, internalState}) {
+
+  let update = (val) => {
+
+    if( configs.hook )
+    {
+      return configs.hook( val ).then( _val => { return onUpdate(_val); } );
+    }
+
+    return onUpdate( val );
+  };
+
   return (
     <table className="PropertyString" style={tableStyle}>
       <tbody>
@@ -14,7 +26,7 @@ export default function PropertyString({value, onUpdate, configs, sourceElement,
           <td>
             <FormTextInput
               value={value}
-              onChange={event => onUpdate(event.target.value)}/>
+              onChange={event => update(event.target.value)}/>
           </td>
         </tr>
       </tbody>
