@@ -1,4 +1,5 @@
-import React, {PropTypes} from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 import PanelElementEditor from './panel-element-editor/panel-element-editor';
 import PanelLayers from './panel-layers';
 import PanelGuides from './panel-guides';
@@ -11,11 +12,11 @@ const STYLE = {
   overflowX: "hidden"
 };
 
-export default function Sidebar({state, width, height}) {
+export default function Sidebar({state, width, height, sidebarComponents}) {
 
   return (
     <aside
-      style={{width, width, height, ...STYLE}}
+      style={{width, height, ...STYLE}}
       onKeyDown={event => event.stopPropagation()}
       onKeyUp={event => event.stopPropagation()}
       className="sidebar"
@@ -24,12 +25,13 @@ export default function Sidebar({state, width, height}) {
       <div className="layer-elements"><PanelLayerElements state={state}/></div>
       <div className="properties"><PanelElementEditor state={state}/></div>
       {/*<div className="guides"><PanelGuides state={state}/></div>*/}
+      {sidebarComponents.map((Component, index) => <Component mode={state.mode} key={index}/>)}
     </aside>
   );
 }
 
 Sidebar.propTypes = {
   state: PropTypes.object.isRequired,
-  width: React.PropTypes.number.isRequired,
-  height: React.PropTypes.number.isRequired
+  width: PropTypes.number.isRequired,
+  height: PropTypes.number.isRequired
 };
